
from __future__ import unicode_literals, print_function

from unittest import TestCase

from packed import Elem


class TestElem(TestCase):

    def test_empty_elem(self):

        elem = Elem('a')

        expected = "<a></a>"

        self.assertEqual(elem.to_html(), expected)

    def test_elem(self):

        elem = Elem('a', {}, Elem('b', {}))

        expected = "<a><b></b></a>"

        self.assertEqual(elem.to_html(), expected)

    def test_empty_elem_single_attribute(self):

        elem = Elem('a', {'class': 'some-icon'})

        expected = '<a class="some-icon"></a>'

        self.assertEqual(elem.to_html(), expected)

    def test_elem_single_attribute(self):

        elem = Elem('a', {'class': 'some-icon'}, Elem('b', {}))

        expected = '<a class="some-icon"><b></b></a>'

        self.assertEqual(elem.to_html(), expected)

    def test_elem_multiple_attribute(self):

        elem = Elem('a', {'class': 'some-icon', 'data-width': 800}, Elem('b', {}))

        expected = '<a data-width="800" class="some-icon"><b></b></a>'

        self.assertEqual(elem.to_html(), expected)

    def test_elem_with_text_child(self):

        elem = Elem('a', {}, 'My link text')

        expected = "<a>My link text</a>"

        self.assertEqual(elem.to_html(), expected)
